==> helm-annotations-3.3.0-sources.jar: io/dekorate/helm/config/ValueReferenceBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ValueReferenceBuilder extends ValueReferenceFluentImpl<ValueReferenceBuilder> implements VisitableBuilder<ValueReference,ValueReferenceBuilder>{
  public ValueReferenceBuilder() {
    this(false);
  }
  public ValueReferenceBuilder(Boolean validationEnabled) {
    this(new ValueReference(), validationEnabled);
  }
  public ValueReferenceBuilder(ValueReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public ValueReferenceBuilder(ValueReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ValueReference(), validationEnabled);
  }
  public ValueReferenceBuilder(ValueReferenceFluent<?> fluent,ValueReference instance) {
    this(fluent, instance, false);
  }
  public ValueReferenceBuilder(ValueReferenceFluent<?> fluent,ValueReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProperty(instance.getProperty()); 
    fluent.withPaths(instance.getPaths()); 
    fluent.withProfile(instance.getProfile()); 
    fluent.withValue(instance.getValue()); 
    fluent.withExpression(instance.getExpression()); 
    this.validationEnabled = validationEnabled; 
  }
  public ValueReferenceBuilder(ValueReference instance) {
    this(instance,false);
  }
  public ValueReferenceBuilder(ValueReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withProperty(instance.getProperty()); 
    this.withPaths(instance.getPaths()); 
    this.withProfile(instance.getProfile()); 
    this.withValue(instance.getValue()); 
    this.withExpression(instance.getExpression()); 
    this.validationEnabled = validationEnabled; 
  }
  ValueReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public EditableValueReference build() {
    EditableValueReference buildable = new EditableValueReference(fluent.getProperty(),fluent.getPaths(),fluent.getProfile(),fluent.getValue(),fluent.getExpression());
    return buildable;
  }
  
}

==> helm-annotations-3.5.4-sources.jar: io/dekorate/helm/config/ValueReferenceBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ValueReferenceBuilder extends ValueReferenceFluentImpl<ValueReferenceBuilder> implements VisitableBuilder<ValueReference,ValueReferenceBuilder>{
  public ValueReferenceBuilder() {
    this(false);
  }
  public ValueReferenceBuilder(Boolean validationEnabled) {
    this(new ValueReference(), validationEnabled);
  }
  public ValueReferenceBuilder(ValueReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public ValueReferenceBuilder(ValueReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ValueReference(), validationEnabled);
  }
  public ValueReferenceBuilder(ValueReferenceFluent<?> fluent,ValueReference instance) {
    this(fluent, instance, false);
  }
  public ValueReferenceBuilder(ValueReferenceFluent<?> fluent,ValueReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProperty(instance.getProperty()); 
    fluent.withPaths(instance.getPaths()); 
    fluent.withProfile(instance.getProfile()); 
    fluent.withValue(instance.getValue()); 
    fluent.withExpression(instance.getExpression()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withMinimum(instance.getMinimum()); 
    fluent.withMaximum(instance.getMaximum()); 
    fluent.withPattern(instance.getPattern()); 
    fluent.withRequired(instance.getRequired()); 
    this.validationEnabled = validationEnabled; 
  }
  public ValueReferenceBuilder(ValueReference instance) {
    this(instance,false);
  }
  public ValueReferenceBuilder(ValueReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withProperty(instance.getProperty()); 
    this.withPaths(instance.getPaths()); 
    this.withProfile(instance.getProfile()); 
    this.withValue(instance.getValue()); 
    this.withExpression(instance.getExpression()); 
    this.withDescription(instance.getDescription()); 
    this.withMinimum(instance.getMinimum()); 
    this.withMaximum(instance.getMaximum()); 
    this.withPattern(instance.getPattern()); 
    this.withRequired(instance.getRequired()); 
    this.validationEnabled = validationEnabled; 
  }
  ValueReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public EditableValueReference build() {
    EditableValueReference buildable = new EditableValueReference(fluent.getProperty(),fluent.getPaths(),fluent.getProfile(),fluent.getValue(),fluent.getExpression(),fluent.getDescription(),fluent.getMinimum(),fluent.getMaximum(),fluent.getPattern(),fluent.getRequired());
    return buildable;
  }
  
}
